@@ -7,7 +7,7 @@ import string
 
 import gi
 gi.require_version("Gtk", "3.0")
-from gi.repository import Gtk, GdkPixbuf
+from gi.repository import Gtk
 
 from mintupload_core import *
 
